==> fujicoin-22.0.1.tar.gz: fujicoin-22.0.1/src/qt/locale/fujicoin_ky.ts <==
<TS version="2.1" language="ky">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаң даректи жасоо</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Ө&amp;чүрүү</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Дарек</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакциялар</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Жардам</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Эскертүү</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Маалымат</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңыланган</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Терезе</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Fujicoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Капчык</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Дарек</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">версия</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Тармак</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">Капчык</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Терезе</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Жарайт</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Жокко чыгаруу</translation>
    </message>
    <message>
        <source>default</source>
        <translation>жарыяланбаган</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">жок</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ката</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Дарек</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">&amp;Тармак</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Маалымат</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Жалпы</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>&amp;Тармак</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Аты</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ачуу</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Консоль</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Консолду тазалоо</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Билдирүү</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бардыгын тазалоо</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Жөнөтүү</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бардыгын тазалоо</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Билдирүү</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Дарек</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ката</translation>
    </message>
    </context>
</TS>

==> fujicoin-23.0.tar.gz: fujicoin-23.0/src/qt/locale/fujicoin_ky.ts <==
<TS version="2.1" language="ky">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Жаң даректи жасоо</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">Ө&amp;чүрүү</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Дарек</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Транзакциялар</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Жардам</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ката</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Эскертүү</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Маалымат</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Жаңыланган</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Терезе</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Fujicoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Капчык</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Дарек</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ката</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">версия</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Даректи алмашуу буферинен коюу</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Тармак</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">Капчык</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;Порт:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Терезе</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;Жарайт</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Жокко чыгаруу</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">жарыяланбаган</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">жок</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ката</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Дарек</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">&amp;Тармак</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">Маалымат</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Жалпы</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">&amp;Тармак</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Аты</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Ачуу</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation type="unfinished">&amp;Консоль</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation type="unfinished">Консолду тазалоо</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Билдирүү</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">&amp;Бардыгын тазалоо</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;Жөнөтүү</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">&amp;Бардыгын тазалоо</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Билдирүү</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(аты жок)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Дарек</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ката</translation>
    </message>
    </context>
</TS>
